pub enum Error {
InternalError,
RequestError(String),
InvalidUrl(InvalidUrl),
InvalidHeaderName(InvalidHeaderName),
InvalidHeaderValue(InvalidHeaderValue),
}Expand description
An error while trying to make an http call.
Variants
InternalError
An internal error occurred within Momento.
RequestError(String)
An error while making a request. Under construction, may become structured errors in the future.
InvalidUrl(InvalidUrl)
The provided URL was not valid.
InvalidHeaderName(InvalidHeaderName)
A provided header name was not valid.
InvalidHeaderValue(InvalidHeaderValue)
A provided header value was not valid.